> Hi,
> 
> The following patch will set the display resolution to 1368x768 for 
> Lynloong all-in-one computers, which is their native resolution. Currently 
> their resolution is being set to 1024x600 which prevents the screen from 
> working properly.
> 
> Tested on my LM9002. (maybe I should update all the docs as well?)
> 

here is a better version with space before parenthesis.

Index: sys/arch/loongson/dev/smfb.c
===================================================================
RCS file: /cvs/src/sys/arch/loongson/dev/smfb.c,v
retrieving revision 1.19
diff -u -r1.19 smfb.c
--- sys/arch/loongson/dev/smfb.c        25 May 2020 09:55:48 -0000      1.19
+++ sys/arch/loongson/dev/smfb.c        2 Jan 2021 12:26:49 -0000
@@ -20,7 +20,8 @@
  * SiliconMotion SM502 and SM712 frame buffer driver.
  *
  * Assumes its video output is an LCD panel, in 5:6:5 mode, and fixed
  * 1024x600 or 800x480 resolution, depending on the system model.
  */
 
 #include <sys/param.h>
@@ -389,9 +390,12 @@
                ri->ri_width = 800;
                ri->ri_height = 480;
                break;
+       case LOONGSON_LYNLOONG:
+               ri->ri_width = 1368;
+               ri->ri_height = 768;
+               break;
        default:
        case LOONGSON_GDIUM:
-       case LOONGSON_LYNLOONG:
        case LOONGSON_YEELOONG:
                ri->ri_width = 1024;
                ri->ri_height = 600;
@@ -20,7 +20,8 @@
  *
  * Assumes its video output is an LCD panel, in 5:6:5 mode, and fixed
- * 1024x600 or 800x480 resolution, depending on the system model.
+ * 1024x600 (Yeeloong) or 1368x768 (Lynloong) or 800x480 (EBT700)
+ * resolution depending on the system model.
  */
 

Reply via email to